==> vrt_lss_routing-3.2.160311.tar.gz: vrt_lss_routing-3.2.160311/vrt_lss_routing/task_schema.py <==
PLAN_TASK_SCHEMA = '''{
    "additionalProperties": false,
    "properties": {
        "departure_time": {
            "format": "date-time",
            "type": "string"
        },
        "detail": {
            "default": true,
            "type": "boolean"
        },
        "geo_provider": {
            "maxLength": 256,
            "minLength": 1,
            "type": "string"
        },
        "result_timezone": {
            "default": 0,
            "format": "int32",
            "maximum": 12,
            "minimum": -12,
            "type": "integer"
        },
        "transport_type": {
            "default": "CAR",
            "enum": [
                "CAR",
                "TRUCK",
                "CAR_GT",
                "TUK_TUK",
                "BICYCLE",
                "PEDESTRIAN",
                "PUBLIC_TRANSPORT"
            ],
            "nullable": false,
            "type": "string"
        },
        "waypoints": {
            "items": {
                "additionalProperties": false,
                "nullable": true,
                "properties": {
                    "duration": {
                        "default": 0,
                        "format": "int32",
                        "maximum": 43800,
                        "minimum": 0,
                        "type": "integer"
                    },
                    "latitude": {
                        "format": "double",
                        "maximum": 90,
                        "minimum": -90,
                        "type": "number"
                    },
                    "longitude": {
                        "format": "double",
                        "maximum": 180,
                        "minimum": -180,
                        "type": "number"
                    }
                },
                "required": [
                    "latitude",
                    "longitude"
                ],
                "type": "object"
            },
            "maxItems": 9000,
            "minItems": 2,
            "type": "array",
            "uniqueItems": false
        }
    },
    "required": [
        "waypoints"
    ],
    "type": "object"
}'''

==> vrt_lss_routing-3.4.161326.tar.gz: vrt_lss_routing-3.4.161326/vrt_lss_routing/task_schema.py <==
ROUTE_TASK_SCHEMA = '''{
    "additionalProperties": false,
    "properties": {
        "departure_time": {
            "format": "date-time",
            "type": "string"
        },
        "detail": {
            "default": false,
            "type": "boolean"
        },
        "geo_provider": {
            "maxLength": 256,
            "minLength": 1,
            "type": "string"
        },
        "polyline": {
            "default": true,
            "type": "boolean"
        },
        "result_timezone": {
            "default": 0,
            "format": "int32",
            "maximum": 12,
            "minimum": -12,
            "type": "integer"
        },
        "transport_type": {
            "default": "CAR",
            "enum": [
                "CAR",
                "TRUCK",
                "CAR_GT",
                "TUK_TUK",
                "BICYCLE",
                "PEDESTRIAN",
                "PUBLIC_TRANSPORT"
            ],
            "nullable": false,
            "type": "string"
        },
        "waypoints": {
            "items": {
                "additionalProperties": false,
                "nullable": true,
                "properties": {
                    "duration": {
                        "default": 0,
                        "format": "int32",
                        "maximum": 43800,
                        "minimum": 0,
                        "type": "integer"
                    },
                    "latitude": {
                        "format": "double",
                        "maximum": 90,
                        "minimum": -90,
                        "type": "number"
                    },
                    "longitude": {
                        "format": "double",
                        "maximum": 180,
                        "minimum": -180,
                        "type": "number"
                    },
                    "name": {
                        "maxLength": 1024,
                        "minLength": 0,
                        "type": "string"
                    }
                },
                "required": [
                    "latitude",
                    "longitude"
                ],
                "type": "object"
            },
            "maxItems": 9000,
            "minItems": 2,
            "type": "array",
            "uniqueItems": false
        }
    },
    "required": [
        "waypoints"
    ],
    "type": "object"
}'''
